Actions, Resources, and Condition Keys for AWS Data Exchange - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Data Exchange

AWS Data Exchange (service prefix: `dataexchange` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Data Exchange
- Resource Types Defined by AWS Data Exchange
- Condition Keys for AWS Data Exchange

## Actions Defined by AWS Data Exchange

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CancelJob | Grants permissions to cancel a job. | Write | jobs* |  |
CreateDataSet | Grants permission to create a data set. | Write |  | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreateJob | Grants permissions to create a job to import or export assets. | Write | jobs* |  |
CreateRevision | Grants permission to create a revision. | Write |  | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
DeleteAsset | Grants permissions to delete an asset. | Write | assets* |  |
DeleteDataSet | Grants permissions to delete a data set. | Write | data-sets* |  |
DeleteRevision | Grants permissions to delete a revision. | Write | revisions* |  |
GetAsset | Grants permissions to get information about an asset. | Read | assets* |  |
GetDataSet | Grants permission to get information about a data set. | Read | data-sets* |  |
GetJob | Grants permissions to get information about a job. | Write | jobs* |  |
GetRevision | Grants permission to get information about a revision. | Read | revisions* |  |
ListDataSetRevisions | Grants permissions to list the revisions of a data set. | List | revisions* |  |
ListDataSets | Grants permission to list data sets for the account. | List | data-sets* |  |
ListJobs | Grants permissions to list jobs for the account. | List | jobs* |  |
ListRevisionAssets | Grants permissions to get list the assets of a revision. | List | assets* |  |
ListTagsForResource | Grants permission to list the tags that you associated with the specified resource. | Read | data-sets |  |
revisions |  |
StartJob | Grants permissions to start a job. | Write | jobs* |  |
TagResource | Grants permission to add one or more tags to a specified resource. | Tagging | data-sets |  |
revisions |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tags from a specified resource. | Tagging | data-sets |  |
revisions |  |
| aws:TagKeys |
UpdateAsset | Grants permissions to get update information about an asset. | Write | assets* |  |
UpdateDataSet | Grants permissions to update information about a data set. | Write | data-sets* |  |
UpdateRevision | Grants permissions to update information about a revision. | Write | revisions* |  |

## Resource Types Defined by AWS Data Exchange

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
jobs | `arn:$ { Partition}:dataexchange:$ { Region}:$ { Account}:jobs/$ { JobId}` | dataexchange:JobType
data-sets | `arn:$ { Partition}:dataexchange:$ { Region}:$ { Account}:data-sets/$ { DataSetId}` |
revisions | `arn:$ { Partition}:dataexchange:$ { Region}:$ { Account}:data-sets/$ { DataSetId}/revisions/$ { RevisionId}` |
assets | `arn:$ { Partition}:dataexchange:$ { Region}:$ { Account}:data-sets/$ { DataSetId}/revisions/$ { RevisionId}/assets/$ { AssetId}` |

## Condition Keys for AWS Data Exchange

AWS Data Exchange defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters create requests based on the allowed set of values for each of the mandatory tags. | String
aws:ResourceTag/$ { TagKey} | Filters actions based on the tag value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String
dataexchange:JobType | Indicates that the action can only be performed on the specified job type. | String